@@ -7,12 +7,15 @@ class Distro(Module):
     - test deploy
     - test remote
     - test run
+    - test REPL
     '''
 
     def deploy(self, target, **kw):
 
         target.deploy('infos')
+        target.pip.install('setux_desktop')
         target.remote('infos')
+        target.pip.install('setux_repl')
         target('setux infos')
 
         return True
