@@ -1,17 +1,14 @@
 from setux.core.module import Module
 
 
-def ping(target, pong='pong'):
-    ret, out, err = target.run('echo', pong)
-    response = out[0]
-    return response==pong
-
-
 class Distro(Module):
     '''Check Target Reachability
     '''
     def deploy(self, target, **kw):
-        return ping(target, pong=kw.get('pong'))
+        pong = kw.get('pong', 'pong')
+        ret, out, err = target.run('echo', pong, report='verbose')
+        response = out[0]
+        return response==pong
 
 
 class debian_9(Distro):
